@@ -379,10 +379,10 @@
 #define TYPE color_15
 #define INIT int64_t fac_1, fac_2, fac_3, fac_4;        \
   int64_t tmp; \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 #define NO_UINT8
 
@@ -416,10 +416,10 @@
 #define TYPE color_16
 #define INIT int64_t fac_1, fac_2, fac_3, fac_4;\
   int64_t tmp;                                                  \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 
 #define NO_UINT8
@@ -453,10 +453,10 @@
 #define FUNC_NAME scale_uint8_x_1_y_bicubic_c
 #define TYPE uint8_t
 #define INIT int64_t fac_1, fac_2, fac_3, fac_4, tmp;               \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 #define SCALE                  \
   tmp = (fac_1 * src_1[0] + \
@@ -473,10 +473,10 @@
 #define FUNC_NAME scale_uint8_x_2_y_bicubic_c
 #define TYPE uint8_t
 #define INIT int64_t fac_1, fac_2, fac_3, fac_4, tmp;               \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 #define SCALE                  \
   tmp = (fac_1 * src_1[0] + \
@@ -501,10 +501,10 @@
 #define FUNC_NAME scale_uint8_x_3_y_bicubic_c
 #define TYPE uint8_t
 #define INIT int64_t fac_1, fac_2, fac_3, fac_4, tmp;               \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 #define SCALE               \
   tmp = (fac_1 * src_1[0] +    \
@@ -535,10 +535,10 @@
 #define FUNC_NAME scale_uint8_x_4_y_bicubic_c
 #define TYPE uint8_t
 #define INIT int64_t fac_1, fac_2, fac_3, fac_4, tmp;               \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 #define SCALE               \
   tmp = (fac_1 * src_1[0] +    \
@@ -579,10 +579,10 @@
 #define TYPE uint16_t
 #define INIT int64_t tmp; \
   int64_t fac_1, fac_2, fac_3, fac_4;                           \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];   \
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];   \
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];   \
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];   \
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];   \
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];   \
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 #define NO_UINT8
 
@@ -602,10 +602,10 @@
 #define TYPE uint16_t
 #define INIT int64_t tmp; \
   int64_t fac_1, fac_2, fac_3, fac_4;                           \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];   \
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];   \
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];   \
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];   \
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];   \
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];   \
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 #define NO_UINT8
 
@@ -632,10 +632,10 @@
 #define TYPE uint16_t
 #define INIT int64_t tmp;                      \
   int64_t fac_1, fac_2, fac_3, fac_4;                           \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 #define NO_UINT8
 
@@ -669,10 +669,10 @@
 #define TYPE uint16_t
 #define INIT int64_t tmp;\
   int64_t fac_1, fac_2, fac_3, fac_4;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_i[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_i[3];
 
 #define NO_UINT8
 
@@ -712,10 +712,10 @@
 #define FUNC_NAME scale_float_x_1_y_bicubic_c
 #define TYPE float
 #define INIT float fac_1, fac_2, fac_3, fac_4;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_f[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_f[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_f[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_f[3];
 
 #define NO_UINT8
   
@@ -733,10 +733,10 @@
 #define FUNC_NAME scale_float_x_2_y_bicubic_c
 #define TYPE float
 #define INIT float fac_1, fac_2, fac_3, fac_4;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_f[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_f[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_f[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_f[3];
 
 #define NO_UINT8
   
@@ -758,10 +758,10 @@
 #define FUNC_NAME scale_float_x_3_y_bicubic_c
 #define TYPE float
 #define INIT float fac_1, fac_2, fac_3, fac_4;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_f[2];\
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_f[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_f[2];\
+  fac_4 = ctx->table_v.pixels[scanline].factor_f[3];
 
 #define NO_UINT8
   
@@ -788,10 +788,10 @@
 #define FUNC_NAME scale_float_x_4_y_bicubic_c
 #define TYPE float
 #define INIT float fac_1, fac_2, fac_3, fac_4;                  \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];   \
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];   \
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_f[2];   \
-  fac_4 = ctx->table_v.pixels[ctx->scanline].factor_f[3];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];   \
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];   \
+  fac_3 = ctx->table_v.pixels[scanline].factor_f[2];   \
+  fac_4 = ctx->table_v.pixels[scanline].factor_f[3];
 
 #define NO_UINT8
 
