@@ -310,8 +310,8 @@
 #define TYPE color_15
 #define INIT int64_t fac_1, fac_2;        \
   int64_t tmp; \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 #define NO_UINT8
 
@@ -339,8 +339,8 @@
 #define TYPE color_16
 #define INIT int64_t fac_1, fac_2;\
   int64_t tmp;                                                  \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 
 #define NO_UINT8
@@ -368,8 +368,8 @@
 #define FUNC_NAME scale_uint8_x_1_y_bilinear_c
 #define TYPE uint8_t
 #define INIT int64_t fac_1, fac_2, tmp;               \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 #define SCALE                  \
   tmp = (fac_1 * src_1[0] + \
@@ -384,8 +384,8 @@
 #define FUNC_NAME scale_uint8_x_2_y_bilinear_c
 #define TYPE uint8_t
 #define INIT int64_t fac_1, fac_2, tmp;               \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 #define SCALE                  \
   tmp = (fac_1 * src_1[0] + \
@@ -406,8 +406,8 @@
 #define FUNC_NAME scale_uint8_x_3_y_bilinear_c
 #define TYPE uint8_t
 #define INIT int64_t fac_1, fac_2, tmp;               \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 #define SCALE               \
   tmp = (fac_1 * src_1[0] +    \
@@ -432,8 +432,8 @@
 #define FUNC_NAME scale_uint8_x_4_y_bilinear_c
 #define TYPE uint8_t
 #define INIT int64_t fac_1, fac_2, tmp;               \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 #define SCALE               \
   tmp = (fac_1 * src_1[0] +    \
@@ -466,8 +466,8 @@
 #define TYPE uint16_t
 #define INIT int64_t tmp; \
   int64_t fac_1, fac_2;                           \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];   \
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];   \
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 #define NO_UINT8
 
@@ -485,8 +485,8 @@
 #define TYPE uint16_t
 #define INIT int64_t tmp; \
   int64_t fac_1, fac_2;                           \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];   \
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];   \
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 #define NO_UINT8
 
@@ -509,8 +509,8 @@
 #define TYPE uint16_t
 #define INIT int64_t tmp;                      \
   int64_t fac_1, fac_2;                           \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 #define NO_UINT8
 
@@ -538,8 +538,8 @@
 #define TYPE uint16_t
 #define INIT int64_t tmp;\
   int64_t fac_1, fac_2;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];
 
 #define NO_UINT8
 
@@ -571,8 +571,8 @@
 #define FUNC_NAME scale_float_x_1_y_bilinear_c
 #define TYPE float
 #define INIT float fac_1, fac_2;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];
 
 #define NO_UINT8
   
@@ -588,8 +588,8 @@
 #define FUNC_NAME scale_float_x_2_y_bilinear_c
 #define TYPE float
 #define INIT float fac_1, fac_2;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];
 
 #define NO_UINT8
   
@@ -607,8 +607,8 @@
 #define FUNC_NAME scale_float_x_3_y_bilinear_c
 #define TYPE float
 #define INIT float fac_1, fac_2;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];
 
 #define NO_UINT8
   
@@ -629,8 +629,8 @@
 #define FUNC_NAME scale_float_x_4_y_bilinear_c
 #define TYPE float
 #define INIT float fac_1, fac_2;                  \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];   \
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];   \
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];
 
 #define NO_UINT8
 
