@@ -257,9 +257,9 @@
 #define FUNC_NAME scale_rgb_15_y_quadratic_c
 #define TYPE color_15
 #define INIT int fac_1, fac_2, fac_3;                           \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 #define NO_UINT8
 
@@ -280,9 +280,9 @@
 #define FUNC_NAME scale_rgb_16_y_quadratic_c
 #define TYPE color_16
 #define INIT int fac_1, fac_2, fac_3;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 #define NO_UINT8
 
@@ -303,9 +303,9 @@
 #define FUNC_NAME scale_uint8_x_1_y_quadratic_c
 #define TYPE uint8_t
 #define INIT int fac_1, fac_2, fac_3;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 #define SCALE                  \
   dst[0] = DOWNSHIFT(fac_1 * src_1[0] + \
@@ -318,9 +318,9 @@
 #define FUNC_NAME scale_uint8_x_2_y_quadratic_c
 #define TYPE uint8_t
 #define INIT int fac_1, fac_2, fac_3;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 #define SCALE                  \
   dst[0] = DOWNSHIFT(fac_1 * src_1[0] + \
@@ -337,9 +337,9 @@
 #define FUNC_NAME scale_uint8_x_3_y_quadratic_c
 #define TYPE uint8_t
 #define INIT int fac_1, fac_2, fac_3;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 #define SCALE                  \
   dst[0] = DOWNSHIFT(fac_1 * src_1[0] + \
@@ -358,9 +358,9 @@
 #define FUNC_NAME scale_uint8_x_4_y_quadratic_c
 #define TYPE uint8_t
 #define INIT int fac_1, fac_2, fac_3;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 
 #define SCALE                  \
@@ -384,9 +384,9 @@
 #define TYPE uint16_t
 #define INIT uint32_t tmp; \
   int fac_1, fac_2, fac_3;                                      \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 #define NO_UINT8
 
@@ -403,9 +403,9 @@
 #define TYPE uint16_t
 #define INIT uint32_t tmp; \
   int fac_1, fac_2, fac_3;                                      \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 #define NO_UINT8
 
@@ -426,9 +426,9 @@
 #define TYPE uint16_t
 #define INIT uint32_t tmp;                      \
   int fac_1, fac_2, fac_3;                                            \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 
 #define NO_UINT8
@@ -455,9 +455,9 @@
 #define TYPE uint16_t
 #define INIT uint32_t tmp;\
   int fac_1, fac_2, fac_3;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_i[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_i[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_i[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_i[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_i[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_i[2];
 
 
 
@@ -487,9 +487,9 @@
 #define FUNC_NAME scale_float_x_1_y_quadratic_c
 #define TYPE float
 #define INIT float fac_1, fac_2, fac_3;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_f[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_f[2];
 
 #define NO_UINT8
   
@@ -504,9 +504,9 @@
 #define FUNC_NAME scale_float_x_2_y_quadratic_c
 #define TYPE float
 #define INIT float fac_1, fac_2, fac_3;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_f[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_f[2];
 
 #define NO_UINT8
   
@@ -524,9 +524,9 @@
 #define FUNC_NAME scale_float_x_3_y_quadratic_c
 #define TYPE float
 #define INIT float fac_1, fac_2, fac_3;\
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];\
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];\
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_f[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];\
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];\
+  fac_3 = ctx->table_v.pixels[scanline].factor_f[2];
 
 #define NO_UINT8
   
@@ -547,9 +547,9 @@
 #define FUNC_NAME scale_float_x_4_y_quadratic_c
 #define TYPE float
 #define INIT float fac_1, fac_2, fac_3;                         \
-  fac_1 = ctx->table_v.pixels[ctx->scanline].factor_f[0];   \
-  fac_2 = ctx->table_v.pixels[ctx->scanline].factor_f[1];   \
-  fac_3 = ctx->table_v.pixels[ctx->scanline].factor_f[2];
+  fac_1 = ctx->table_v.pixels[scanline].factor_f[0];   \
+  fac_2 = ctx->table_v.pixels[scanline].factor_f[1];   \
+  fac_3 = ctx->table_v.pixels[scanline].factor_f[2];
 
 #define NO_UINT8
 
