@@ -18,7 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * *****************************************************************/
-static void (FUNC_NAME)(gavl_video_scale_context_t * ctx)
+static void (FUNC_NAME)(gavl_video_scale_context_t * ctx, int scanline, uint8_t * dest_start)
   {
   int i;
 
@@ -58,7 +58,7 @@ static void (FUNC_NAME)(gavl_video_scale_context_t * ctx)
   INIT
 #endif
   
-  _src_1 = ctx->src + ctx->table_v.pixels[ctx->scanline].index * ctx->src_stride;
+  _src_1 = ctx->src + ctx->table_v.pixels[scanline].index * ctx->src_stride;
 #if NUM_TAPS > 1
   _src_2 = _src_1 + ctx->src_stride;
 #endif
@@ -71,7 +71,7 @@ static void (FUNC_NAME)(gavl_video_scale_context_t * ctx)
   
   for(i = 0; i < ctx->dst_size; i++)
     {
-    dst = (TYPE*)(ctx->dst);
+    dst = (TYPE*)(dest_start);
 #ifdef NO_UINT8  
     src_1 = (TYPE*)(_src_1);
 #if NUM_TAPS > 1
@@ -88,7 +88,7 @@ static void (FUNC_NAME)(gavl_video_scale_context_t * ctx)
     
     SCALE
     
-    ctx->dst += ctx->offset->dst_advance;
+    dest_start += ctx->offset->dst_advance;
     _src_1 += ctx->offset->src_advance;
 #if NUM_TAPS > 1
     _src_2 += ctx->offset->src_advance;
