@@ -61,17 +61,25 @@ void gavl_video_scaler_destroy(gavl_video_scaler_t * s)
 gavl_video_scaler_t * gavl_video_scaler_create()
   {
   gavl_video_scaler_t * ret;
+  int i, j;
   ret = calloc(1, sizeof(*ret));
 
   ret->src = gavl_video_frame_create((gavl_video_format_t*)0);
   ret->dst = gavl_video_frame_create((gavl_video_format_t*)0);
 
   gavl_video_options_set_defaults(&ret->opt);
+
+  for(i = 0; i < 3; i++)
+    {
+    for(j = 0; j < GAVL_MAX_PLANES; j++)
+      ret->contexts[i][j].opt = &ret->opt;
+    }
   
   return ret;
   }
 
-void gavl_init_scale_funcs(gavl_scale_funcs_t * tab, gavl_video_options_t * opt,
+void gavl_init_scale_funcs(gavl_scale_funcs_t * tab,
+                           gavl_video_options_t * opt,
                            int src_advance, int dst_advance,
                            gavl_video_scale_table_t * tab_h,
                            gavl_video_scale_table_t * tab_v)
@@ -481,8 +489,8 @@ int gavl_video_scaler_init(gavl_video_scaler_t * scaler,
 
 int gavl_video_scaler_init_convolve(gavl_video_scaler_t * scaler,
                                     const gavl_video_format_t * format,
-                                    int h_radius, float * h_coeffs,
-                                    int v_radius, float * v_coeffs)
+                                    int h_radius, const float * h_coeffs,
+                                    int v_radius, const float * v_coeffs)
   {
   gavl_rectangle_f_t src_rect;
   gavl_rectangle_i_t  dst_rect;
