@@ -48,26 +48,28 @@ void * memalign (size_t align, size_t size);
 
 #define EPS 1e-4 /* Needed to determine if a double and an int are equal. */
 
-static void copy_scanline_noadvance(gavl_video_scale_context_t * ctx)
+static void copy_scanline_noadvance(gavl_video_scale_context_t * ctx, int scanline,
+                                    uint8_t * dest_start)
   {
-  //  fprintf(stderr, "copy_scanline_noadvance\n");
-  gavl_memcpy(ctx->dst, ctx->src, ctx->bytes_per_line);
-  ctx->src += ctx->src_stride;
+  //  fprintf(stderr, "copy_scanline_noadvance %d\n", scanline);
+  gavl_memcpy(dest_start, ctx->src + ctx->src_stride * scanline, ctx->bytes_per_line);
+  //  ctx->src += ctx->src_stride;
   }
 
-static void copy_scanline_advance(gavl_video_scale_context_t * ctx)
+static void copy_scanline_advance(gavl_video_scale_context_t * ctx, int scanline,
+                                  uint8_t * dest_start)
   {
   int i;
-  uint8_t * src = ctx->src;
+  uint8_t * src = ctx->src + ctx->src_stride * scanline;
   //  fprintf(stderr, "copy_scanline_advance\n");
   for(i = 0; i < ctx->dst_rect.w; i++)
     {
-    *ctx->dst = *src;
+    *dest_start = *src;
 
-    ctx->dst += ctx->offset->dst_advance;
+    dest_start += ctx->offset->dst_advance;
     src += ctx->offset->src_advance;
     }
-  ctx->src += ctx->src_stride;
+  //  ctx->src += ctx->src_stride;
   }
 
 /* Debugging utility */
@@ -826,40 +828,14 @@ int gavl_video_scale_context_init(gavl_video_scale_context_t*ctx,
           ctx->max_values_h[1],
           ctx->max_values_h[2]);
 #endif
-#if 0
-  for(i = 0; i < 4; i++)
-    {
-    ctx->min_values_h[i] <<= bits_h;
-    ctx->max_values_h[i] <<= bits_h;
-
-    ctx->min_values_v[i] <<= bits_v;
-    ctx->max_values_v[i] <<= bits_v;
-    }
-#endif
-#if 0
-  fprintf(stderr, "Min: %d %d %d, max: %d %d %d\n",
-          ctx->min_values_h[0],
-          ctx->min_values_h[1],
-          ctx->min_values_h[2],
-          ctx->max_values_h[0],
-          ctx->max_values_h[1],
-          ctx->max_values_h[2]);
-#endif
     
-#if 0
-  for(i = 0; i < 4; i++)
-    {
-    fprintf(stderr, "Channel %d: min: %08x, max: %08x\n", i,
-            ctx->min_values[i], ctx->max_values[i]);
-    }
-#endif
   return 1;
   }
 
 /* Factor must be a power of 2 */
 
 static void downsample_coeffs(int factor,
-                              float * coeffs, int num_coeffs,
+                              const float * coeffs, int num_coeffs,
                               float ** coeffs_ret, 
                               int * num_coeffs_ret)
   {
@@ -933,10 +909,10 @@ gavl_video_scale_context_init_convolve(gavl_video_scale_context_t* ctx,
                                        int plane,
                                        const gavl_video_format_t * format,
                                        int num_fields,
-                                       int h_radius, float * h_coeffs,
-                                       int v_radius, float * v_coeffs)
+                                       int h_radius, const float * h_coeffs,
+                                       int v_radius, const float * v_coeffs)
   {
-  int bits_h = 1, bits_v = 1, i;
+  int bits_h = 1, bits_v = 1;
   int sub_h = 1, sub_v = 1;
   int scale_x, scale_y;
 
@@ -947,9 +923,11 @@ gavl_video_scale_context_init_convolve(gavl_video_scale_context_t* ctx,
   gavl_rectangle_i_t src_rect_i;
 
   int h_radius_real;
-  float * h_coeffs_real, *h_c = (float*)0;
+  const float * h_coeffs_real;
+  float *h_c = (float*)0;
   int v_radius_real;
-  float * v_coeffs_real, *v_c = (float*)0;
+  const float * v_coeffs_real;
+  float *v_c = (float*)0;
 
   int src_width, src_height; /* Needed for generating the scale table */
  
@@ -1079,7 +1057,6 @@ gavl_video_scale_context_init_convolve(gavl_video_scale_context_t* ctx,
     gavl_pixelformat_is_planar(format->pixelformat) ?
     ctx->dst_rect.w * gavl_pixelformat_bytes_per_component(format->pixelformat) :
     ctx->dst_rect.w * gavl_pixelformat_bytes_per_pixel(format->pixelformat);
-
   
   /* Set source and destination offsets */
 
@@ -1167,7 +1144,7 @@ gavl_video_scale_context_init_convolve(gavl_video_scale_context_t* ctx,
     if((tmp_opt.scale_mode == tmp_opt_y.scale_mode) &&
        (tmp_opt.scale_order == tmp_opt_y.scale_order))
       {
-        gavl_init_scale_funcs(&funcs, &tmp_opt,
+      gavl_init_scale_funcs(&funcs, &tmp_opt,
                             ctx->offset1.src_advance,
                             ctx->offset2.dst_advance,
                             &(ctx->table_h), &(ctx->table_v));
@@ -1271,13 +1248,6 @@ gavl_video_scale_context_init_convolve(gavl_video_scale_context_t* ctx,
   
   get_minmax(format->pixelformat, ctx->min_values_h, ctx->max_values_h, ctx->min_values_f, ctx->max_values_f);
   get_minmax(format->pixelformat, ctx->min_values_v, ctx->max_values_v, ctx->min_values_f, ctx->max_values_f);
-  for(i = 0; i < 4; i++)
-    {
-    ctx->min_values_h[i] <<= bits_h;
-    ctx->max_values_h[i] <<= bits_h;
-    ctx->min_values_v[i] <<= bits_v;
-    ctx->max_values_v[i] <<= bits_v;
-    }
 
   if(h_c) free(h_c);
   if(v_c) free(v_c);
@@ -1293,19 +1263,188 @@ void gavl_video_scale_context_cleanup(gavl_video_scale_context_t * ctx)
     free(ctx->buffer);
   }
 
+static void func_1(void* p, int start, int end)
+  {
+  int i;
+  uint8_t * dst_save;
+  
+  gavl_video_scale_context_t * ctx = p;
+
+  dst_save = ctx->dst_frame->planes[ctx->dst_frame_plane] + ctx->offset->dst_offset +
+    start * ctx->dst_frame->strides[ctx->dst_frame_plane];
+
+  for(i = start; i < end; i++)
+    {
+    ctx->func1(ctx, i, dst_save);
+    dst_save += ctx->dst_frame->strides[ctx->dst_frame_plane];
+    }
+#ifdef HAVE_MMX
+  __asm__ __volatile__ ("emms");
+#endif
+
+  }
+
+static void func_1_of_2(void* p, int start, int end)
+  {
+  int i;
+  uint8_t * dst_save;
+  gavl_video_scale_context_t * ctx = p;
+  
+  dst_save = ctx->buffer + start * ctx->buffer_stride;
+  for(i = start; i < end; i++)
+    {
+    ctx->func1(ctx, i, dst_save);
+    dst_save += ctx->buffer_stride;
+    }
+#ifdef HAVE_MMX
+  __asm__ __volatile__ ("emms");
+#endif
+  
+  }
+
+static void func_2_of_2(void* p, int start, int end)
+  {
+  int i;
+  uint8_t * dst_save;
+  gavl_video_scale_context_t * ctx = p;
+  dst_save =
+    ctx->dst_frame->planes[ctx->dst_frame_plane] + ctx->offset->dst_offset +
+    start * ctx->dst_frame->strides[ctx->dst_frame_plane];
+
+  for(i = start; i < end; i++)
+    {
+    ctx->func2(ctx, i, dst_save);
+    dst_save += ctx->dst_frame->strides[ctx->dst_frame_plane];
+    }
+#ifdef HAVE_MMX
+  __asm__ __volatile__ ("emms");
+#endif
+  }
+
+
+static void scale_context_scale_mt(gavl_video_scale_context_t * ctx,
+                                   const gavl_video_frame_t * src,
+                                   gavl_video_frame_t * dst)
+  {
+  int delta;
+  int scanline;
+  int nt;
+  int i;
+  switch(ctx->num_directions)
+    {
+    case 1:
+      /* Only step */
+      ctx->src = src->planes[ctx->src_frame_plane] + ctx->offset->src_offset;
+      ctx->src_stride = src->strides[ctx->src_frame_plane];
+      ctx->dst_frame = dst;
+      
+      nt = ctx->opt->num_threads;
+      if(nt > ctx->dst_rect.h)
+        nt = ctx->dst_rect.h;
+      
+      delta = ctx->dst_rect.h / nt;
+      scanline = 0;
+      for(i = 0; i < nt - 1; i++)
+        {
+        ctx->opt->run_func(func_1, ctx, scanline, scanline+delta, ctx->opt->run_data, i);
+        
+        //        fprintf(stderr, "scanline: %d (%d)\n", ctx->scanline, ctx->dst_rect.h);
+        scanline += delta;
+        }
+      ctx->opt->run_func(func_1, ctx, scanline, ctx->dst_rect.h, ctx->opt->run_data, nt - 1);
+      
+      for(i = 0; i < nt; i++)
+        ctx->opt->stop_func(ctx->opt->stop_data, i);
+      break;
+    case 2:
+      /* First step */
+      ctx->offset = &(ctx->offset1);
+      
+      ctx->src = src->planes[ctx->src_frame_plane] +
+        ctx->offset->src_offset +
+        src->strides[ctx->src_frame_plane] * ctx->first_scanline;
+      
+      ctx->src_stride = src->strides[ctx->src_frame_plane];
+      ctx->dst_size = ctx->buffer_width;
+
+#if 0
+      fprintf(stderr, "First direction\n");
+      dump_offset(ctx->offset);
+#endif
+
+      nt = ctx->opt->num_threads;
+      if(nt > ctx->buffer_height)
+        nt = ctx->buffer_height;
+
+      delta = ctx->buffer_height / nt;
+      scanline = 0;
+      for(i = 0; i < nt - 1; i++)
+        {
+        ctx->opt->run_func(func_1_of_2, ctx, scanline, scanline+delta, ctx->opt->run_data, i);
+        
+        //        fprintf(stderr, "scanline: %d (%d)\n", ctx->scanline, ctx->dst_rect.h);
+        scanline += delta;
+        }
+      ctx->opt->run_func(func_1_of_2, ctx, scanline, ctx->buffer_height,
+                         ctx->opt->run_data, nt - 1);
+      
+      for(i = 0; i < nt; i++)
+        ctx->opt->stop_func(ctx->opt->stop_data, i);
+      
+      //      fprintf(stderr, "done\n");
+
+      /* Second step */
+      ctx->offset = &(ctx->offset2);
+#if 0
+      fprintf(stderr, "Second direction\n");
+      dump_offset(ctx->offset);
+#endif
+      ctx->src = ctx->buffer;
+      ctx->src_stride = ctx->buffer_stride;
+      ctx->dst_size = ctx->dst_rect.w;
+      ctx->dst_frame = dst;
+      
+      nt = ctx->opt->num_threads;
+      if(nt > ctx->dst_rect.h)
+        nt = ctx->dst_rect.h;
+      
+      delta = ctx->dst_rect.h / nt;
+
+      scanline = 0;
+      for(i = 0; i < nt - 1; i++)
+        {
+        ctx->opt->run_func(func_2_of_2, ctx, scanline, scanline+delta, ctx->opt->run_data, i);
+        
+        //        fprintf(stderr, "scanline: %d (%d)\n", ctx->scanline, ctx->dst_rect.h);
+        scanline += delta;
+        }
+      ctx->opt->run_func(func_2_of_2, ctx, scanline, ctx->dst_rect.h,
+                         ctx->opt->run_data, nt - 1);
+      
+      for(i = 0; i < nt; i++)
+        ctx->opt->stop_func(ctx->opt->stop_data, i);
+      //      fprintf(stderr, "done\n");
+      break;
+    }
+  }
 
 void gavl_video_scale_context_scale(gavl_video_scale_context_t * ctx,
                                     const gavl_video_frame_t * src,
                                     gavl_video_frame_t * dst)
   {
   uint8_t * dst_save;
+  int i;
+  
+  if(ctx->opt->num_threads > 1)
+    {
+    scale_context_scale_mt(ctx, src, dst);
+    return;
+    }
+  
   //  fprintf(stderr, "gavl_video_scale_context_scale, plane %d\n",
   //          ctx->dst_frame_plane);
   switch(ctx->num_directions)
     {
-    case 0:
-      /* Copy field plane */
-      break;
     case 1:
       /* Only step */
       ctx->src = src->planes[ctx->src_frame_plane] + ctx->offset->src_offset;
@@ -1313,11 +1452,10 @@ void gavl_video_scale_context_scale(gavl_video_scale_context_t * ctx,
 
       dst_save = dst->planes[ctx->dst_frame_plane] + ctx->offset->dst_offset;
             
-      for(ctx->scanline = 0; ctx->scanline < ctx->dst_rect.h; ctx->scanline++)
+      for(i = 0; i < ctx->dst_rect.h; i++)
         {
         //        fprintf(stderr, "scanline: %d (%d)\n", ctx->scanline, ctx->dst_rect.h);
-        ctx->dst = dst_save;
-        ctx->func1(ctx);
+        ctx->func1(ctx, i, dst_save);
         dst_save += dst->strides[ctx->dst_frame_plane];
         }
       break;
@@ -1338,10 +1476,9 @@ void gavl_video_scale_context_scale(gavl_video_scale_context_t * ctx,
       dump_offset(ctx->offset);
 #endif
       
-      for(ctx->scanline = 0; ctx->scanline < ctx->buffer_height; ctx->scanline++)
+      for(i = 0; i < ctx->buffer_height; i++)
         {
-        ctx->dst = dst_save;
-        ctx->func1(ctx);
+        ctx->func1(ctx, i, dst_save);
         dst_save += ctx->buffer_stride;
         }
       //      fprintf(stderr, "done\n");
@@ -1357,11 +1494,11 @@ void gavl_video_scale_context_scale(gavl_video_scale_context_t * ctx,
       ctx->dst_size = ctx->dst_rect.w;
       dst_save =
         dst->planes[ctx->dst_frame_plane] + ctx->offset->dst_offset;
-      for(ctx->scanline = 0; ctx->scanline < ctx->dst_rect.h; ctx->scanline++)
+
+      for(i = 0; i < ctx->dst_rect.h; i++)
         {
         //        fprintf(stderr, "i: %d\n", ctx->scanline);
-        ctx->dst = dst_save;
-        ctx->func2(ctx);
+        ctx->func2(ctx, i, dst_save);
         dst_save += dst->strides[ctx->dst_frame_plane];
         }
       //      fprintf(stderr, "done\n");
