@@ -29,6 +29,8 @@
 
 #define BLUR_THRESHOLD 5.0e-3
 
+// #define DUMP_TABLE
+
 /* Conversion between src and dst coordinates */
 
 #define DST_TO_SRC(c) ((double)c)/scale_factor+src_off
@@ -292,16 +294,15 @@ void gavl_video_scale_table_init(gavl_video_scale_table_t * tab,
     
   //  fprintf(stderr, "After shift %d\n", src_width);
   //if(deinterlace || (total_fields == 2))
-  //  gavl_video_scale_table_dump(tab);
-
-  
-  
+#ifdef DUMP_TABLE
+  gavl_video_scale_table_dump(tab);
+#endif  
   }
 
 void 
 gavl_video_scale_table_init_convolve(gavl_video_scale_table_t * tab,
                                      gavl_video_options_t * opt,
-                                     int num_coeffs, float * coeffs,
+                                     int num_coeffs, const float * coeffs,
                                      int size)
   {
   int i, j;
@@ -488,8 +489,8 @@ void gavl_video_scale_table_dump(gavl_video_scale_table_t * tab)
       //              tab->pixels[i].factor[j].fac_f,
       //              tab->pixels[i].factor[j].fac_i);
 
-      fprintf(stderr, ", fac[%d]: %f ", tab->pixels[i].index + j,
-              tab->pixels[i].factor_f[j]);
+      fprintf(stderr, ", fac[%d]: %f (%d) ", tab->pixels[i].index + j,
+              tab->pixels[i].factor_f[j], tab->pixels[i].factor_i[j]);
       
       sum += tab->pixels[i].factor_f[j];
       }
