@@ -152,8 +152,8 @@ static void video_frame_alloc(gavl_video_frame_t * ret,
     case GAVL_YUV_420_P:
     case GAVL_YUVJ_420_P:
       ret->strides[0] = format->frame_width;
-      ret->strides[1] = format->frame_width/2;
-      ret->strides[2] = format->frame_width/2;
+      ret->strides[1] = (format->frame_width+1)/2;
+      ret->strides[2] = (format->frame_width+1)/2;
 
       if(align)
         {
@@ -163,15 +163,15 @@ static void video_frame_alloc(gavl_video_frame_t * ret,
         }
       ret->planes[0] = memalign(ALIGNMENT_BYTES,
                              ret->strides[0]*format->frame_height+
-                             (ret->strides[1]*format->frame_height)/2+
-                             (ret->strides[2]*format->frame_height)/2);
+                             ret->strides[1]*((format->frame_height+1)/2)+
+                             ret->strides[2]*((format->frame_height+1)/2));
       ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
-      ret->planes[2] = ret->planes[1] + (ret->strides[1]*format->frame_height)/2;
+      ret->planes[2] = ret->planes[1] + ret->strides[1]*((format->frame_height+1)/2);
       break;
     case GAVL_YUV_410_P:
       ret->strides[0] = format->frame_width;
-      ret->strides[1] = format->frame_width/4;
-      ret->strides[2] = format->frame_width/4;
+      ret->strides[1] = (format->frame_width+3)/4;
+      ret->strides[2] = (format->frame_width+3)/4;
 
       if(align)
         {
@@ -182,16 +182,16 @@ static void video_frame_alloc(gavl_video_frame_t * ret,
       
       ret->planes[0] = memalign(ALIGNMENT_BYTES,
                              ret->strides[0]*format->frame_height+
-                             (ret->strides[1]*format->frame_height)/4+
-                             (ret->strides[2]*format->frame_height)/4);
+                             ret->strides[1]*((format->frame_height+3)/4)+
+                             ret->strides[2]*((format->frame_height+3)/4));
       ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
-      ret->planes[2] = ret->planes[1] + (ret->strides[1]*format->frame_height)/4;
+      ret->planes[2] = ret->planes[1] + ret->strides[1]*((format->frame_height+3)/4);
       break;
     case GAVL_YUV_422_P:
     case GAVL_YUVJ_422_P:
       ret->strides[0] = format->frame_width;
-      ret->strides[1] = format->frame_width/2;
-      ret->strides[2] = format->frame_width/2;
+      ret->strides[1] = (format->frame_width+1)/2;
+      ret->strides[2] = (format->frame_width+1)/2;
 
       if(align)
         {
@@ -201,18 +201,18 @@ static void video_frame_alloc(gavl_video_frame_t * ret,
         }
       
       ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0]*format->frame_height+
-                             ret->strides[1]*format->frame_height+
-                             ret->strides[2]*format->frame_height);
+                                ret->strides[0]*format->frame_height+
+                                ret->strides[1]*format->frame_height+
+                                ret->strides[2]*format->frame_height);
 
       ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
       ret->planes[2] = ret->planes[1] + ret->strides[1]*format->frame_height;
       break;
     case GAVL_YUV_422_P_16:
       ret->strides[0] = format->frame_width*2;
-      ret->strides[1] = format->frame_width;
-      ret->strides[2] = format->frame_width;
-
+      ret->strides[1] = ((format->frame_width+1)/2)*2;
+      ret->strides[2] = ((format->frame_width+1)/2)*2;
+      
       if(align)
         {
         ALIGN(ret->strides[0]);
@@ -230,8 +230,8 @@ static void video_frame_alloc(gavl_video_frame_t * ret,
       break;
     case GAVL_YUV_411_P:
       ret->strides[0] = format->frame_width;
-      ret->strides[1] = format->frame_width/4;
-      ret->strides[2] = format->frame_width/4;
+      ret->strides[1] = (format->frame_width+3)/4;
+      ret->strides[2] = (format->frame_width+3)/4;
 
       if(align)
         {
@@ -1312,7 +1312,7 @@ static void fill_16_packed(gavl_video_frame_t * frame,
 
 static void fill_24_packed(gavl_video_frame_t * frame,
                            const gavl_video_format_t * format,
-                           uint8_t * color)
+                           const uint8_t * color)
   {
   FILL_FUNC_HEAD_PACKED(uint8_t);
   dst[0] = color[0];
@@ -1323,7 +1323,7 @@ static void fill_24_packed(gavl_video_frame_t * frame,
 
 static void fill_32_packed(gavl_video_frame_t * frame,
                            const gavl_video_format_t * format,
-                           uint8_t * _color)
+                           const uint8_t * _color)
   {
   uint32_t * color = (uint32_t*)_color;
   FILL_FUNC_HEAD_PACKED(uint32_t);
@@ -1333,7 +1333,7 @@ static void fill_32_packed(gavl_video_frame_t * frame,
 
 static void fill_32_packed_422(gavl_video_frame_t * frame,
                                const gavl_video_format_t * format,
-                               uint8_t * _color)
+                               const uint8_t * _color)
   {
   uint32_t * color = (uint32_t*)_color;
   FILL_FUNC_HEAD_PACKED_422(uint32_t);
@@ -1344,7 +1344,7 @@ static void fill_32_packed_422(gavl_video_frame_t * frame,
 
 static void fill_48_packed(gavl_video_frame_t * frame,
                            const gavl_video_format_t * format,
-                           uint16_t * color)
+                           const uint16_t * color)
   {
   FILL_FUNC_HEAD_PACKED(uint16_t);
   gavl_memcpy(dst, color, 3*sizeof(*dst));
@@ -1353,7 +1353,7 @@ static void fill_48_packed(gavl_video_frame_t * frame,
 
 static void fill_64_packed(gavl_video_frame_t * frame,
                            const gavl_video_format_t * format,
-                           uint16_t * color)
+                           const uint16_t * color)
   {
   FILL_FUNC_HEAD_PACKED(uint16_t);
   gavl_memcpy(dst, color, 4*sizeof(*dst));
@@ -1362,7 +1362,7 @@ static void fill_64_packed(gavl_video_frame_t * frame,
 
 static void fill_float_gray(gavl_video_frame_t * frame,
                            const gavl_video_format_t * format,
-                           float * color)
+                           const float * color)
   {
   FILL_FUNC_HEAD_PACKED(float);
   gavl_memcpy(dst, color, sizeof(*dst));
@@ -1371,7 +1371,7 @@ static void fill_float_gray(gavl_video_frame_t * frame,
 
 static void fill_float_graya(gavl_video_frame_t * frame,
                            const gavl_video_format_t * format,
-                           float * color)
+                           const float * color)
   {
   FILL_FUNC_HEAD_PACKED(float);
   gavl_memcpy(dst, color, 2*sizeof(*dst));
@@ -1380,7 +1380,7 @@ static void fill_float_graya(gavl_video_frame_t * frame,
 
 static void fill_float_rgb(gavl_video_frame_t * frame,
                            const gavl_video_format_t * format,
-                           float * color)
+                           const float * color)
   {
   FILL_FUNC_HEAD_PACKED(float);
   gavl_memcpy(dst, color, 3*sizeof(*dst));
@@ -1389,7 +1389,7 @@ static void fill_float_rgb(gavl_video_frame_t * frame,
 
 static void fill_float_rgba(gavl_video_frame_t * frame,
                             const gavl_video_format_t * format,
-                            float * color)
+                            const float * color)
   {
   FILL_FUNC_HEAD_PACKED(float);
   gavl_memcpy(dst, color, 4*sizeof(*dst));
@@ -1504,7 +1504,7 @@ static void fill_planar_16(gavl_video_frame_t * frame,
 
 void gavl_video_frame_fill(gavl_video_frame_t * frame,
                            const gavl_video_format_t * format,
-                           float * color)
+                           const float * color)
   {
   INIT_RGB_FLOAT_TO_YUV
   uint16_t packed_16;
