@@ -42,10 +42,8 @@ typedef struct gavl_mix_input_channel_s
   int index; /* Which input channel */
   union      /* Weighing factor     */
     {
-    double    f_float;
-    int8_t   f_8;
-    int16_t  f_16;
-    int32_t  f_32;
+    double  f_float;
+    int     f_int;
     } factor;
   } gavl_mix_input_channel_t;
 
